<# The sample scripts are not supported under any Microsoft standard support 
 program or service. The sample scripts are provided AS IS without warranty  
 of any kind. Microsoft further disclaims all implied warranties including,  
 without limitation, any implied warranties of merchantability or of fitness for 
 a particular purpose. The entire risk arising out of the use or performance of  
 the sample scripts and documentation remains with you. In no event shall 
 Microsoft, its authors, or anyone else involved in the creation, production, or 
 delivery of the scripts be liable for any damages whatsoever (including, 
 without limitation, damages for loss of business profits, business interruption, 
 loss of business information, or other pecuniary loss) arising out of the use 
 of or inability to use the sample scripts or documentation, even if Microsoft 
 has been advised of the possibility of such damages 
#>

Function CheckIndexesIssues
{
	PARAM
	(
		[Parameter(Mandatory=$true,Position=0)][String]$ServerName
        
	)

	if($ServerName)
	{  
        $SQLConnection = NewSQLConnection $ServerName 
        try{        
			    #Open database
				$SQLConnection.Open()
	             
                ## Get the version of the server
                #Get the instance name 
                if($ServerName = $env:COMPUTERNAME)
                {
                $InstanceName = "MSSQLSERVER"     
                }
                elseif(($ServerName -ne $env:COMPUTERNAME) -and ($ServerName.split("\")[0] -eq $env:COMPUTERNAME))
                {
                 $InstanceName = $ServerName.split("\")[1]     
                }

                #Get the build of the server
                $sn= (Get-ItemProperty 'HKLM:\SOFTWARE\Microsoft\Microsoft SQL Server\Instance Names\SQL').$InstanceName
	            $version=(Get-ItemProperty "HKLM:\SOFTWARE\Microsoft\Microsoft SQL Server\$sn\Setup").Version
                $Build=$version.Split(".")
                $Major=[int]$Build[0]
               
           
                if(($Major -eq 9 ) -or ($Major -eq 10 ) -or ($Major -eq 11 ) )
                {
	                #SQL query statement to check indexes issues in databases
                    $SQLQuery = "
                                -- Check the current database for common issues such as:
                                --	tables with no indexes
                                --	tables with no clustered index but with non-clustered indexes
                                --	tables with more indexes than columns

                                -- tables with no indexes
                                SELECT s.name AS SchemaName, t.name AS ObjectName
                                FROM sys.indexes AS si 
                                INNER JOIN sys.tables AS t 
                                ON si.[object_id] = t.[object_id]
                                INNER JOIN sys.schemas AS s 
                                ON s.[schema_id] = t.[schema_id]
                                GROUP BY si.[object_id], t.name, s.name
                                HAVING COUNT(index_id) = 1 AND MAX(index_id) = 0

                                 
                                --tables with no clustered index but with non-clustered indexes
                                SELECT s.name AS SchemaName, t.name AS ObjectName
                                FROM sys.indexes AS si 
                                INNER JOIN sys.tables AS t ON si.[object_id] = t.[object_id]
                                INNER JOIN sys.schemas AS s ON s.[schema_id] = t.[schema_id]
                                GROUP BY t.name, s.name
                                HAVING COUNT(index_id) > 1 AND MIN(index_id) = 0


                                --tables with more indexes than columns
                                SELECT s.name AS SchemaName, t.name AS ObjectName, COUNT(c.column_id) AS ColumnNumber , 
                                (SELECT COUNT(si.index_id) 
                                 FROM sys.tables AS t2 
                                 INNER JOIN sys.indexes AS si 
                                 ON si.[object_id] = t2.[object_id]
                                 WHERE si.index_id > 0 AND si.[object_id] = t.[object_id]
                                 GROUP BY si.[object_id]) AS IndexNumber
                                FROM sys.tables AS t 
                                INNER JOIN sys.columns AS c ON t.[object_id] = c.[object_id] 
                                INNER JOIN sys.schemas AS s ON s.[schema_id] = t.[schema_id]
                                GROUP BY s.name, t.name, t.[object_id]
                                HAVING COUNT(c.column_id) < (SELECT COUNT(si.index_id) 
                                						 FROM sys.tables AS t2 
                                						 INNER JOIN sys.indexes AS si 
                                						 ON si.[object_id] = t2.[object_id]
                                						 WHERE si.index_id > 0 AND si.[object_id] = t.[object_id]
                                						 GROUP BY si.[object_id])                    
                                "
                            
                    #Create SQLDataAdapter object with command text and connection
			        $SQLDataSet = New-Object System.Data.DataSet
			        $SQLAdapter = New-Object System.Data.SqlClient.SqlDataAdapter($SQLQuery,$SQLConnection)
                                       
			        $SQLAdapter.Fill($SQLDataSet) | Out-Null
                  
                    #To show the result
                    Write-Host "-----------------------"
                    Write-Host "tables with no indexes"
                    Write-Host "-----------------------"
                    $SQLDataSet.Tables[0]| Format-List
                    Write-Host "--------------------------------------------------------------"
                    Write-Host "tables with no clustered index but with non-clustered indexes"
                    Write-Host "--------------------------------------------------------------"
                    $SQLDataSet.Tables[1]| Format-List
                    Write-Host "-------------------------------------"
                    Write-Host "tables with more indexes than columns"
                    Write-Host "-------------------------------------"
                    $SQLDataSet.Tables[2]| Format-List
                }
                else 
                {
                Write-Host "The version of this instance $ServerName is not SQL Server 2005, SQL Server 2008 or SQL Server 2012!"
                }
                
            }
        catch 
		{
				Write-Error $_
		}
    }
}
	
        
Function GetChoice($message)
{
    $Win = New-Object System.Management.Automation.Host.ChoiceDescription "&Windows","Windows authentication"
    $SQL = New-Object System.Management.Automation.Host.ChoiceDescription "&SQL Server","SQL Server authentication"
    $Quit = New-Object System.Management.Automation.Host.ChoiceDescription "&Quit","Choose to quit"
    $choices = [System.Management.Automation.Host.ChoiceDescription[]]($Win,$SQL,$Quit)
    $caption = "Confirming"
    $result = $Host.UI.PromptForChoice($caption,$message,$choices,0)
    $result
}
        
Function NewSQLConnection
{
	
    PARAM
	(
		[String]$ServerName
        
	)
	   
	if($ServerName)
	{
        $Choice = Getchoice("Select Windows or SQL Server authentication")
        
        ## Windows Authentication
        if($choice -eq 0)
        {
		    #Create SqlConnection object and define connection string
		    $Connection = New-Object System.Data.SqlClient.SqlConnection
		    $ConnectionB = New-Object System.Data.SqlClient.SqlConnectionStringBuilder
		    $ConnectionB["Data Source"] = $ServerName
		    $ConnectionB["Database"] = $DatabaseName
		    $ConnectionB["Trusted_Connection"] = "SSPI"
		    $Connection.ConnectionString = $ConnectionB.ConnectionString
        }
  
        ## SQL Server Authentication 
        if($choice -eq 1)
        {

		    #Use Get-Credentical to get username and password and then create SQLConnection,define connection string        
            $credentical = Get-Credential
		    $userName = Invoke-Command -ScriptBlock {PARAM([string]$targetStr)
		    if($targetStr.ToCharArray()[0] -eq "\"){$targetStr.Substring(1,$targetStr.Length-1)}else{$targetStr}
					    } -ArgumentList $credentical.UserName
		    $password = [Runtime.InteropServices.Marshal]::PtrToStringAuto(`
					    [Runtime.InteropServices.Marshal]::SecureStringToBSTR($credentical.Password))
		    $Connection = New-Object System.Data.SqlClient.SqlConnection
		    $ConnectionB = New-Object System.Data.SqlClient.SqlConnectionStringBuilder
		    $ConnectionB["Data Source"] = $ServerName
		    $ConnectionB["Database"] = "master"
		    $ConnectionB["User ID"] = $UserName
		    $ConnectionB["Password"] = $password
		    $Connection.ConnectionString = $ConnectionB.ConnectionString
		}		
		# Store SqlConnection object
		$Connection        
	}
}

CheckIndexesIssues