-- Tables: 
-- TIME_ZONES
-- TZCD ?VARCHAR(6) NOT NULL - Represents the short code of timezones (eg 'UTC', 'IST' etc) without daylight timezones 
-- TZNAME ?VARCHAR(60) NOT NULL - Represents the name to describe the time zone code (eg 'Indian Standard Time' etc)
-- TZLOCATION VARCHAR(60) NOT NULL - Represents the location the timezone is applicable for (ie, 'North America', 'Asia' etc)
-- OFFSETSIGN CHAR(1) NULL - Represents the offset sign respective to UTC timezone (eg '+' or '-')
-- OFFSETMI?INT NOT NULL - Represents the offset time in mintes for adjusting the date time
-- DSTOFFSAPP CHAR(1) NULL - Represents if the day light timezone is applicable or not
-- TZCDDL ?VARCHAR(6) NULL - Represents the short code of daylight timezones (eg 'EDT' etc)

-- Notes: This table holds the time zone related date used to convert date time values
-- 
-- Functions: 
-- ufnGetTZDateTime
-- @DT DATETIME - Represents the datetime needs to be converted
-- @OLDTZCD VARCHAR(6) - Time Zone code (must match a value in the database table) representing the timezone for @DT value
-- @OLDTZLOCATION VARCHAR(20) - Time Zone location (must match a value in the database table) representing the timezone location for @DT,OLDTZCD values
-- @NEWTZCD VARCHAR(6) - Time Zone code (must match a value in the database table) representing the timezone for which the @DT value needs to be converted
-- @NEWTZLOCATION VARCHAR(20) - Time Zone code (must match a value in the database table) representing the timezone location for which the @DT value needs to be converted

-- Notes: if UTC or GMT is passed as timezone code then location information needs not to be passed.

/****** Object: Table [dbo].[TIME_ZONES] ******/ 
IF EXISTS 
( 
    SELECT * FROM dbo.sysobjects 
    WHERE id = object_id ( N'[DF_TIME_ZONES_OFFSETSIGN]' ) 
    AND type = 'D' 
) 
BEGIN 
    ALTER TABLE [dbo].[TIME_ZONES] DROP CONSTRAINT [DF_TIME_ZONES_OFFSETSIGN] 
END 
GO 

IF EXISTS 
( 
    SELECT * FROM dbo.sysobjects 
    WHERE id = object_id ( N'[DF_TIME_ZONES_OFFSETMI]' ) 
    AND type = 'D' 
) 
BEGIN 
    ALTER TABLE [dbo].[TIME_ZONES] DROP CONSTRAINT [DF_TIME_ZONES_OFFSETMI] 
END 
GO 

IF EXISTS 
( 
    SELECT * FROM dbo.sysobjects 
    WHERE id = object_id ( N'[DF_TIME_ZONES_DSTOFFSAPP]' ) 
    AND type = 'D' 
) 
BEGIN 
    ALTER TABLE [dbo].[TIME_ZONES] DROP CONSTRAINT [DF_TIME_ZONES_DSTOFFSAPP] 
END 
GO 

-- if exists drop the table
IF EXISTS 
( 
    SELECT * FROM sys.objects 
    WHERE object_id = object_id ( N'[dbo].[TIME_ZONES]' ) 
    AND type IN ( N'U' ) 
) 
DROP TABLE [dbo].[TIME_ZONES] 
GO 

/****** Object: Table [dbo].[TIME_ZONES] ******/ 
SET ANSI_NULLS ON 
GO 
SET QUOTED_IDENTIFIER ON 
GO 
SET ANSI_PADDING ON 
GO 

-- create table
IF NOT EXISTS 
( 
    SELECT * FROM sys.objects 
    WHERE object_id = object_id ( N'[dbo].[TIME_ZONES]' ) 
    AND type IN ( N'U' ) 
) 
BEGIN 
    CREATE TABLE [dbo].[TIME_ZONES] 
    ( 
        [TZCD] [varchar] ( 6 ) NOT NULL , 
        [TZNAME] [varchar] ( 60 ) NOT NULL , 
        [TZLOCATION] [varchar] ( 20 ) NOT NULL , 
        [OFFSETSIGN] [char] ( 1 ) NULL CONSTRAINT [DF_TIME_ZONES_OFFSETSIGN] DEFAULT ( '+' ) , 
        [OFFSETMI] [int] NOT NULL CONSTRAINT [DF_TIME_ZONES_OFFSETMI] DEFAULT ( ( 0 ) ) , 
        [DSTOFFSAPP] [char] ( 1 ) NULL CONSTRAINT [DF_TIME_ZONES_DSTOFFSAPP] DEFAULT ( 'N' ) , 
        [TZCDDL] [varchar] ( 6 ) NULL , 
        CONSTRAINT [PK_TIME_ZONES] PRIMARY KEY CLUSTERED 
        ( 
            [TZCD] ASC , 
            [TZNAME] ASC , 
            [TZLOCATION] ASC 
        ) 
        WITH ( PAD_INDEX = OFF , STATISTICS_NORECOMPUTE = OFF , IGNORE_DUP_KEY = OFF , ALLOW_ROW_LOCKS = ON , ALLOW_PAGE_LOCKS = ON ) ON [PRIMARY] 
    ) 
    ON [PRIMARY] 
END 
GO 

SET ANSI_PADDING OFF 
GO 

-- insert data
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'A' , N'Alpha Time Zone' , N'Military' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AFT' , N'Afghanistan Time' , N'Asia' , N'+' , 270 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AKST' , N'Alaska Standard Time' , N'North America' , N'-' , 540 , N'Y' , N'AKDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ALMT' , N'Alma-Ata Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AMST' , N'Amazon Summer Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AMST' , N'Armenia Summer Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AMT' , N'Amazon Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AMT' , N'Armenia Time' , N'Asia' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ANAST' , N'Anadyr Summer Time' , N'Asia' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ANAT' , N'Anadyr Time' , N'Asia' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AQTT' , N'Aqtobe Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ART' , N'Argentina Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AST' , N'Arabia Standard Time' , N'Asia' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AST' , N'Atlantic Standard Time' , N'Atlantic' , N'-' , 240 , N'Y' , N'ADT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AST' , N'Atlantic Standard Time' , N'Caribbean' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AST' , N'Atlantic Standard Time' , N'North America' , N'-' , 240 , N'Y' , N'ADT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AZOST' , N'Azores Summer Time' , N'Atlantic' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AZOT' , N'Azores Time' , N'Atlantic' , N'-' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AZST' , N'Azerbaijan Summer Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'AZT' , N'Azerbaijan Time' , N'Asia' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'B' , N'Bravo Time Zone' , N'Military' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BNT' , N'Brunei Darussalam Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BOT' , N'Bolivia Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BRST' , N'Brasilia Summer Time' , N'South America' , N'-' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BRT' , N'Brasilia time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BST' , N'Bangladesh Standard Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BST' , N'British Summer Time' , N'Europe' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'BTT' , N'Bhutan Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'C' , N'Charlie Time Zone' , N'Military' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CAST' , N'Casey Time' , N'Antarctica' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CAT' , N'Central Africa Time' , N'Africa' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CCT' , N'Cocos Islands Time' , N'Indian Ocean' , N'+' , 390 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CEST' , N'Central European Summer Time' , N'Europe' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CET' , N'Central European Time' , N'Africa' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CET' , N'Central European Time' , N'Europe' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CHAST' , N'Chatham Island Standard Time' , N'Pacific' , N'+' , 765 , N'Y' , N'CHDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ChST' , N'Chamorro Standard Time' , N'Pacific' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CKT' , N'Cook Island Time' , N'Pacific' , N'-' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CLST' , N'Chile Summer Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CLT' , N'Chile Standard Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'COT' , N'Colombia Time' , N'South America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CST' , N'Central Standard Time' , N'Australia' , N'+' , 570 , N'Y' , N'CDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CST' , N'Central Standard Time' , N'Central America' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CST' , N'Central Standard Time' , N'North America' , N'-' , 360 , N'Y' , N'CDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CST' , N'China Standard Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CST' , N'Cuba Standard Time' , N'Caribbean' , N'-' , 300 , N'Y' , N'CDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CVT' , N'Cape Verde Time' , N'Africa' , N'-' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'CXT' , N'Christmas Island Time' , N'Australia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'D' , N'Delta Time Zone' , N'Military' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'DAVT' , N'Davis Time' , N'Antarctica' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'E' , N'Echo Time Zone' , N'Military' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EASST' , N'Easter Island Summer Time' , N'Pacific' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EAST' , N'Easter Island Standard Time' , N'Pacific' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EAT' , N'East Africa Time' , N'Indian Ocean' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EAT' , N'Eastern Africa Time' , N'Africa' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ECT' , N'Ecuador Time' , N'South America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EEST' , N'Eastern European Summer Time' , N'Africa' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EEST' , N'Eastern European Summer Time' , N'Asia' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EEST' , N'Eastern European Summer Time' , N'Europe' , N'+' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EET' , N'Eastern European Time' , N'Africa' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EET' , N'Eastern European Time' , N'Asia' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EET' , N'Eastern European Time' , N'Europe' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EGST' , N'Eastern Greenland Summer Time' , N'North America' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EGT' , N'East Greenland Time' , N'North America' , N'-' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EST' , N'Eastern Standard Time' , N'Australia' , N'+' , 600 , N'Y' , N'EDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EST' , N'Eastern Standard Time' , N'Caribbean' , N'-' , 300 , N'Y' , N'EDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EST' , N'Eastern Standard Time' , N'North America' , N'-' , 300 , N'Y' , N'EDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'EST' , N'Eastern Standard Time' , N'Pacific' , N'-' , 300 , N'Y' , N'EDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ET' , N'Tiempo del Este' , N'Caribbean' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ET' , N'Tiempo del Este' , N'Central America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ET' , N'Tiempo Del Este' , N'North America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'F' , N'Foxtrot Time Zone' , N'Military' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'FJST' , N'Fiji Summer Time' , N'Pacific' , N'+' , 780 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'FJT' , N'Fiji Time' , N'Pacific' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'FKST' , N'Falkland Islands Summer Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'FKT' , N'Falkland Island Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'FNT' , N'Fernando de Noronha Time' , N'South America' , N'-' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'G' , N'Golf Time Zone' , N'Military' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GALT' , N'Galapagos Time' , N'Pacific' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GAMT' , N'Gambier Time' , N'Pacific' , N'-' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GET' , N'Georgia Standard Time' , N'Asia' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GFT' , N'French Guiana Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GILT' , N'Gilbert Island Time' , N'Pacific' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GMT' , N'Greenwich Mean Time' , N'Africa' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GMT' , N'Greenwich Mean Time' , N'Europe' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GST' , N'Gulf Standard Time' , N'Asia' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'GYT' , N'Guyana Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'H' , N'Hotel Time Zone' , N'Military' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAA' , N'Heure Avancee de l''Atlantique' , N'North America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAC' , N'Heure Avancee du Centre' , N'North America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAE' , N'Heure Avancee de l''Est' , N'Caribbean' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAE' , N'Heure Avancee de l''Est' , N'North America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAP' , N'Heure Avancee du Pacifique' , N'North America' , N'-' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAR' , N'Heure Avancee des Rocheuses' , N'North America' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAST' , N'Hawaii-Aleutian Standard Time' , N'North America' , N'-' , 600 , N'Y' , N'HADT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAT' , N'Heure Avancee de Terre-Neuve' , N'North America' , N'-' , 150 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HAY' , N'Heure Avancee du Yukon' , N'North America' , N'-' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HKT' , N'Hong Kong Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HLV' , N'Hora Legal de Venezuela' , N'South America' , N'-' , 270 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNA' , N'Heure Normale de l''Atlantique' , N'Atlantic' , N'-' , 240 , N'Y' , N'HAA' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNA' , N'Heure Normale de l''Atlantique' , N'Caribbean' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNA' , N'Heure Normale de l''Atlantique' , N'North America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNC' , N'Heure Normale du Centre' , N'Central America' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNC' , N'Heure Normale du Centre' , N'North America' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNE' , N'Heure Normale de l''Est' , N'Caribbean' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNE' , N'Heure Normale de l''Est' , N'Central America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNE' , N'Heure Normale de l''Est' , N'North America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNP' , N'Heure Normale du Pacifique' , N'North America' , N'-' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNR' , N'Heure Normale des Rocheuses' , N'North America' , N'-' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNT' , N'Heure Normale de Terre-Neuve' , N'North America' , N'-' , 210 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HNY' , N'Heure Normale du Yukon' , N'North America' , N'-' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'HOVT' , N'Hovd Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'I' , N'India Time Zone' , N'Military' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ICT' , N'Indochina Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IOT' , N'Indian Chagos Time' , N'Indian Ocean' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IRKST' , N'Irkutsk Summer Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IRKT' , N'Irkutsk Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IRST' , N'Iran Standard Time' , N'Asia' , N'+' , 210 , N'Y' , N'IRDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IST' , N'India Standard Time' , N'Asia' , N'+' , 330 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'IST' , N'Irish Standard Time' , N'Europe' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'JST' , N'Japan Standard Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'K' , N'Kilo Time Zone' , N'Military' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'KGT' , N'Kyrgyzstan Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'KRAST' , N'Krasnoyarsk Summer Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'KRAT' , N'Krasnoyarsk Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'KST' , N'Korea Standard Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'KUYT' , N'Kuybyshev Time' , N'Europe' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'L' , N'Lima Time Zone' , N'Military' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'LHST' , N'Lord Howe Standard Time' , N'Australia' , N'+' , 630 , N'Y' , N'LHDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'LINT' , N'Line Islands Time' , N'Pacific' , N'+' , 840 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'M' , N'Mike Time Zone' , N'Military' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MAGST' , N'Magadan Summer Time' , N'Asia' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MAGT' , N'Magadan Time' , N'Asia' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MART' , N'Marquesas Time' , N'Pacific' , N'-' , 570 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MAWT' , N'Mawson Time' , N'Antarctica' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MHT' , N'Marshall Islands Time' , N'Pacific' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MMT' , N'Myanmar Time' , N'Asia' , N'+' , 390 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MSK' , N'Moscow Standard Time' , N'Europe' , N'+' , 180 , N'Y' , N'MSD' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MST' , N'Mountain Standard Time' , N'North America' , N'-' , 420 , N'Y' , N'MDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MUT' , N'Mauritius Time' , N'Africa' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MVT' , N'Maldives Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'MYT' , N'Malaysia Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'N' , N'November Time Zone' , N'Military' , N'-' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NCT' , N'New Caledonia Time' , N'Pacific' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NFT' , N'Norfolk Time' , N'Australia' , N'+' , 690 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NOVST' , N'Novosibirsk Summer Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NOVT' , N'Novosibirsk Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NPT' , N'Nepal Time' , N'Asia' , N'+' , 345 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NST' , N'Newfoundland Standard Time' , N'North America' , N'-' , 210 , N'Y' , N'NDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NUT' , N'Niue Time' , N'Pacific' , N'-' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NZST' , N'New Zealand Standard Time' , N'Antarctica' , N'+' , 720 , N'Y' , N'NZDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'NZST' , N'New Zealand Standard Time' , N'Pacific' , N'+' , 720 , N'Y' , N'NZDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'O' , N'Oscar Time Zone' , N'Military' , N'-' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'OMSST' , N'Omsk Summer Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'OMST' , N'Omsk Standard Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'P' , N'Papa Time Zone' , N'Military' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PET' , N'Peru Time' , N'South America' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PETST' , N'Kamchatka Summer Time' , N'Asia' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PETT' , N'Kamchatka Time' , N'Asia' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PGT' , N'Papua New Guinea Time' , N'Pacific' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PHOT' , N'Phoenix Island Time' , N'Pacific' , N'+' , 780 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PHT' , N'Philippine Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PKT' , N'Pakistan Standard Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PMST' , N'Pierre & Miquelon Standard Time' , N'North America' , N'-' , 180 , N'Y' , N'PMDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PONT' , N'Pohnpei Standard Time' , N'Pacific' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PST' , N'Pacific Standard Time' , N'North America' , N'-' , 480 , N'Y' , N'PST' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PST' , N'Pitcairn Standard Time' , N'Pacific' , N'-' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PT' , N'Tiempo del Pacifico' , N'North America' , N'-' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PWT' , N'Palau Time' , N'Pacific' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PYST' , N'Paraguay Summer Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'PYT' , N'Paraguay Time' , N'South America' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'Q' , N'Quebec Time Zone' , N'Military' , N'-' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'R' , N'Romeo Time Zone' , N'Military' , N'-' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'RET' , N'Reunion Time' , N'Africa' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'S' , N'Sierra Time Zone' , N'Military' , N'-' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SAMT' , N'Samara Time' , N'Europe' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SAST' , N'South Africa Standard Time' , N'Africa' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SBT' , N'Solomon IslandsTime' , N'Pacific' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SCT' , N'Seychelles Time' , N'Africa' , N'+' , 240 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SGT' , N'Singapore Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SRT' , N'Suriname Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'SST' , N'Samoa Standard Time' , N'Pacific' , N'-' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'T' , N'Tango Time Zone' , N'Military' , N'-' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TAHT' , N'Tahiti Time' , N'Pacific' , N'-' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TFT' , N'French Southern and Antarctic Time' , N'Indian Ocean' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TJT' , N'Tajikistan Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TKT' , N'Tokelau Time' , N'Pacific' , N'-' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TLT' , N'East Timor Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TMT' , N'Turkmenistan Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'TVT' , N'Tuvalu Time' , N'Pacific' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'U' , N'Uniform Time Zone' , N'Military' , N'-' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'ULAT' , N'Ulaanbaatar Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'UYST' , N'Uruguay Summer Time' , N'South America' , N'-' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'UYT' , N'Uruguay Time' , N'South America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'UZT' , N'Uzbekistan Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'V' , N'Victor Time Zone' , N'Military' , N'-' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'VET' , N'Venezuelan Standard Time' , N'South America' , N'-' , 270 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'VLAST' , N'Vladivostok Summer Time' , N'Asia' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'VLAT' , N'Vladivostok Time' , N'Asia' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'VUT' , N'Vanuatu Time' , N'Pacific' , N'+' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'W' , N'Whiskey Time Zone' , N'Military' , N'-' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WAST' , N'West Africa Summer Time' , N'Africa' , N'+' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WAT' , N'West Africa Time' , N'Africa' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WEST' , N'Western European Summer Time' , N'Africa' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WEST' , N'Western European Summer Time' , N'Europe' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WET' , N'Western European Time' , N'Africa' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WET' , N'Western European Time' , N'Europe' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WFT' , N'Wallis and Futuna Time' , N'Pacific' , N'+' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WGST' , N'Western Greenland Summer Time' , N'North America' , N'-' , 120 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WGT' , N'West Greenland Time' , N'North America' , N'-' , 180 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WIB' , N'Western Indonesian Time' , N'Asia' , N'+' , 420 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WIT' , N'Eastern Indonesian Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WITA' , N'Central Indonesian Time' , N'Asia' , N'+' , 480 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WST' , N'West Samoa Time' , N'Pacific' , N'-' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WST' , N'Western Sahara Summer Time' , N'Africa' , N'+' , 60 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WST' , N'Western Standard Time' , N'Australia' , N'+' , 480 , N'Y' , N'WDT' ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'WT' , N'Western Sahara Standard Time' , N'Africa' , N'+' , 0 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'X' , N'X-ray Time Zone' , N'Military' , N'-' , 660 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'Y' , N'Yankee Time Zone' , N'Military' , N'-' , 720 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'YAKST' , N'Yakutsk Summer Time' , N'Asia' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'YAKT' , N'Yakutsk Time' , N'Asia' , N'+' , 540 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'YAPT' , N'Yap Time' , N'Pacific' , N'+' , 600 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'YEKST' , N'Yekaterinburg Summer Time' , N'Asia' , N'+' , 360 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'YEKT' , N' Yekaterinburg Time' , N'Asia' , N'+' , 300 , N'N' , NULL ) 
INSERT [dbo].[TIME_ZONES] ( [TZCD] , [TZNAME] , [TZLOCATION] , [OFFSETSIGN] , [OFFSETMI] , [DSTOFFSAPP] , [TZCDDL] ) VALUES ( N'Z' , N'Zulu Time Zone' , N'Military' , N'+' , 0 , N'N' , NULL ) 

-- if exists drop the function
/****** Object: UserDefinedFunction [dbo].[ufnGetTZDateTime] ******/ 
IF EXISTS 
( 
    SELECT * FROM sys.objects 
    WHERE object_id = object_id ( N'[dbo].[ufnGetTZDateTime]' ) 
    AND type IN ( N'FN' , N'IF' , N'TF' , N'FS' , N'FT' ) 
) 
DROP FUNCTION [dbo].[ufnGetTZDateTime] 
GO 

-- create the function
/****** Object: UserDefinedFunction [dbo].[ufnGetTZDateTime] ******/ 
SET ANSI_NULLS ON 
GO 
SET QUOTED_IDENTIFIER ON 
GO 

IF NOT EXISTS 
( 
    SELECT * FROM sys.objects 
    WHERE object_id = object_id ( N'[dbo].[ufnGetTZDateTime]' ) 
    AND type IN ( N'FN' , N'IF' , N'TF' , N'FS' , N'FT' ) 
) 
BEGIN 
    EXECUTE dbo.sp_executesql @statement = N'CREATE FUNCTION [dbo].[ufnGetTZDateTime] 
    (@DT AS DATETIME, 
    @OLDTZCD AS VARCHAR(6),
    @OLDTZLOCATION AS VARCHAR(20),
    @NEWTZCD AS VARCHAR(6),
    @NEWTZLOCATION AS VARCHAR(20)
    )
    RETURNS DATETIME
    AS
    BEGIN

    DECLARE @NEWDT AS DATETIME
    DECLARE @HASDLZN AS CHAR(1)
    DECLARE @UTCDT AS DATETIME 
    DECLARE @DLNEEDTOCONSIDER AS CHAR(1)
    DECLARE @DLOFFSETMI INT
     
    -- set default daylight offset time in minute
    SET @DLOFFSETMI = 60
     
    IF (LTRIM(RTRIM(@OLDTZCD)) = ''GMT'') OR (LTRIM(RTRIM(@OLDTZCD)) = ''UTC'')
      BEGIN
    SET @UTCDT = @DT
      END
    ELSE
      BEGIN
    SET @HASDLZN = ''N''
    
    -- check if daylight saving zone is applicable to the timezone
    IF EXISTS (SELECT * FROM dbo.TIME_ZONES WHERE TZCDDL = @OLDTZCD AND TZLOCATION = @OLDTZLOCATION)
      BEGIN
    SET @HASDLZN = ''Y'' 
      END
    ELSE
      BEGIN
    SET @HASDLZN = ''N''
      END
    
    -- calculate applicable UTC tz datetime?
    IF (@HASDLZN = ''Y'')
      BEGIN
    SELECT @UTCDT = CASE WHEN OFFSETSIGN = ''+'' THEN DATEADD(mi,@DLOFFSETMI,DATEADD(mi,- OFFSETMI,@DT)) ELSE DATEADD(mi,@DLOFFSETMI,DATEADD(mi,OFFSETMI,@DT)) END
    FROM dbo.TIME_ZONES
    WHERE TZCDDL = @OLDTZCD
    AND TZLOCATION = @OLDTZLOCATION
      
      END
    ELSE
      BEGIN
    SELECT @UTCDT = CASE WHEN OFFSETSIGN = ''+'' THEN DATEADD(mi,- OFFSETMI,@DT) ELSE DATEADD(mi,OFFSETMI,@DT) END
    FROM dbo.TIME_ZONES
    WHERE TZCD = @OLDTZCD
    AND TZLOCATION = @OLDTZLOCATION
      END
    
      END 
     
     
    IF (LTRIM(RTRIM(@NEWTZCD)) = ''GMT'') OR (LTRIM(RTRIM(@NEWTZCD)) = ''UTC'')
      BEGIN
    SET @NEWDT = @UTCDT
      END
    ELSE
      BEGIN
    SET @HASDLZN = ''N''
    
    -- check if daylight saving zone is applicable to the timezone
    IF EXISTS (SELECT * FROM dbo.TIME_ZONES WHERE TZCDDL = @NEWTZCD AND TZLOCATION = @NEWTZLOCATION)
      BEGIN
    SET @HASDLZN = ''Y'' 
      END
    ELSE
      BEGIN
    SET @HASDLZN = ''N''
      END
      
    -- calculate applicable new tz date over UTC tz date?
    IF (@HASDLZN = ''Y'')
      BEGIN
      
    SELECT @NEWDT = CASE WHEN OFFSETSIGN = ''-'' THEN DATEADD(mi,@DLOFFSETMI,DATEADD(mi,- OFFSETMI,@UTCDT)) ELSE DATEADD(mi,@DLOFFSETMI,DATEADD(mi,OFFSETMI,@UTCDT)) END
    FROM dbo.TIME_ZONES
    WHERE TZCDDL = @NEWTZCD
    AND TZLOCATION = @NEWTZLOCATION
      
      END
    ELSE
      BEGIN
    SELECT @NEWDT = CASE WHEN OFFSETSIGN = ''-'' THEN DATEADD(mi,- OFFSETMI,@UTCDT) ELSE DATEADD(mi,OFFSETMI,@UTCDT) END
    FROM dbo.TIME_ZONES
    WHERE TZCD = @NEWTZCD
    AND TZLOCATION = @NEWTZLOCATION
      END
      END 

    -- Return the new calculated date
    RETURN @NEWDT
     
    END
    ' 
END 
GO